/*-------------------------------------------------------------------------
 * Copyright (C) 1999	National Center for Supercomputing Applications.
 *			All rights reserved.
 *
 *-------------------------------------------------------------------------
 */

// This is the main CGI program which extracts DDS class descriptors from a
// hdf5 data file. 

#include <ctype.h>

#include "h5dds.h"

extern "C" hid_t get_fileid(const char *);

int
main(int argc, char *argv[])
{
    DDS dds;
    DODSFilter df(argc, argv);

    try {
	if (!df.OK()) {
	    df.print_usage();
	    return 1;
	}

	if (df.version()) {
	    df.send_version_info();
	    return 0;
	}

	string errMsg;

	hid_t file1 = get_fileid(df.get_dataset_name().c_str());

	if (file1 < 0) {
	    errMsg = "unable to open hdf5 file " + df.get_dataset_name();
	    throw Error(no_such_file, errMsg);
	} else {
	    (void) depth_first(file1, "/", dds,
			       df.get_dataset_name().c_str());

	    df.send_dds(dds, true);

	    if (H5Fclose(file1) < 0)
		throw Error(unknown_error,
			    string("Could not close the HDF5 file: ")
			    + df.get_dataset_name());

	    return 0;
	}
    }

    catch(Error & e) {
	cerr << "Server error: " << e.error_message() << endl;

	set_mime_text(cout, dods_error, df.get_cgi_version());
	e.print(cout);
	return 1;
    }
    return 0;
}
